@@ -28,7 +28,7 @@ series0 <- function(m, series, reeval = TRUE, data.frame = FALSE){
     return(data.frame(time = time, df0))
   }
   
-  z <- try(as.xts(z0))
+  z <- try(as_xts_xtsimp(z0))
 
   if (inherits(z, "try-error")){
     z <- try(xts::xts(z0, order.by = as.Date(paste(seq(NROW(z0)), "1", "1", sep = "-"))))
@@ -44,6 +44,8 @@ series0 <- function(m, series, reeval = TRUE, data.frame = FALSE){
   z
 }
 
+
+
 pc <- function(x){
   z <- diff(x) / lag(x, -1)
   if (inherits(z, "mts")){
